@@ -25,12 +25,18 @@ Tomasz Adamusiak <tomasz@cpan.org>
  
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2010 European Bioinformatics Institute. All Rights Reserved.
+Copyright [2011] EMBL - European Bioinformatics Institute
 
-This module is free software; you can redistribute it and/or modify it 
-under GPLv3.
-
-This software is provided "as is" without warranty of any kind.
+Licensed under the Apache License, Version 2.0 (the
+"License"); you may not use this file except in compliance
+with the License. You may obtain a copy of the License at
+http://www.apache.org/licenses/LICENSE-2.0
+Unless required by applicable law or agreed to in writing,
+software distributed under the License is distributed on an
+"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+either express or implied. See the License for the specific
+language governing permissions and limitations under the
+License.
 
 =cut
 
@@ -39,7 +45,7 @@ package EBI::FGPT::FuzzyRecogniser::OntologyTerm;
 use Moose;
 
 
-our $VERSION = 0.07;
+our $VERSION = 0.09;
 
 has 'accession' => ( is => 'rw', isa => 'Str', required => 1 );
 has 'label'     => ( is => 'rw', isa => 'Str', required => 1 );
